==> ldap-account-manager_8.3.orig.tar.bz2: ldap-account-manager-8.3/templates/lib/extra/ckeditor/plugins/table/lang/sq.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'sq', {
	border: 'Madhësia e kornizave',
	caption: 'Titull',
	cell: {
		menu: 'Qeli',
		insertBefore: 'Shto Qeli Para',
		insertAfter: 'Shto Qeli Prapa',
		deleteCell: 'Gris Qelitë',
		merge: 'Bashko Qelitë',
		mergeRight: 'Bashko Djathtas',
		mergeDown: 'Bashko Poshtë',
		splitHorizontal: 'Ndaj Qelinë Horizontalisht',
		splitVertical: 'Ndaj Qelinë Vertikalisht',
		title: 'Rekuizitat e Qelisë',
		cellType: 'Lloji i Qelisë',
		rowSpan: 'Bashko Rreshtat',
		colSpan: 'Bashko Kolonat',
		wordWrap: 'Fund i Fjalës',
		hAlign: 'Bashkimi Horizontal',
		vAlign: 'Bashkimi Vertikal',
		alignBaseline: 'Baza',
		bgColor: 'Ngjyra e Prapavijës',
		borderColor: 'Ngjyra e Kornizave',
		data: 'Të dhënat',
		header: 'Koka',
		yes: 'Po',
		no: 'Jo',
		invalidWidth: 'Gjerësia e qelisë duhet të jetë numër.',
		invalidHeight: 'Lartësia e qelisë duhet të jetë numër.',
		invalidRowSpan: 'Hapësira e rreshtave duhet të jetë numër i plotë.',
		invalidColSpan: 'Hapësira e kolonave duhet të jetë numër i plotë.',
		chooseColor: 'Përzgjidh'
	},
	cellPad: 'Mbushja e qelisë',
	cellSpace: 'Hapësira e qelisë',
	column: {
		menu: 'Kolona',
		insertBefore: 'Vendos Kolonë Para',
		insertAfter: 'Vendos Kolonë Pas',
		deleteColumn: 'Gris Kolonat'
	},
	columns: 'Kolonat',
	deleteTable: 'Gris Tabelën',
	headers: 'Kokat',
	headersBoth: 'Së bashku',
	headersColumn: 'Kolona e parë',
	headersNone: 'Asnjë',
	headersRow: 'Rreshti i Parë',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Madhësia e kufinjve duhet të jetë numër.',
	invalidCellPadding: 'Mbushja e qelisë duhet të jetë numër pozitiv.',
	invalidCellSpacing: 'Hapësira e qelisë duhet të jetë numër pozitiv.',
	invalidCols: 'Numri i kolonave duhet të jetë numër më i madh se 0.',
	invalidHeight: 'Lartësia e tabelës duhet të jetë numër.',
	invalidRows: 'Numri i rreshtave duhet të jetë numër më i madh se 0.',
	invalidWidth: 'Gjerësia e tabelës duhet të jetë numër.',
	menu: 'Karakteristikat e Tabelës',
	row: {
		menu: 'Rreshti',
		insertBefore: 'Shto Rresht Para',
		insertAfter: 'Shto Rresht Prapa',
		deleteRow: 'Gris Rreshtat'
	},
	rows: 'Rreshtat',
	summary: 'Përmbledhje',
	title: 'Karakteristikat e Tabelës',
	toolbar: 'Tabela',
	widthPc: 'përqind',
	widthPx: 'piksell',
	widthUnit: 'njësia e gjerësisë'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/sq.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'sq', {
	border: 'Madhësia e kornizave',
	caption: 'Titull',
	cell: {
		menu: 'Qeli',
		insertBefore: 'Shto Qeli Para',
		insertAfter: 'Shto Qeli Prapa',
		deleteCell: 'Gris Qelitë',
		merge: 'Bashko Qelitë',
		mergeRight: 'Bashko Djathtas',
		mergeDown: 'Bashko Poshtë',
		splitHorizontal: 'Ndaj Qelinë Horizontalisht',
		splitVertical: 'Ndaj Qelinë Vertikalisht',
		title: 'Rekuizitat e Qelisë',
		cellType: 'Lloji i Qelisë',
		rowSpan: 'Bashko Rreshtat',
		colSpan: 'Bashko Kolonat',
		wordWrap: 'Fund i Fjalës',
		hAlign: 'Bashkimi Horizontal',
		vAlign: 'Bashkimi Vertikal',
		alignBaseline: 'Baza',
		bgColor: 'Ngjyra e Prapavijës',
		borderColor: 'Ngjyra e Kornizave',
		data: 'Të dhënat',
		header: 'Koka',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Po',
		no: 'Jo',
		invalidWidth: 'Gjerësia e qelisë duhet të jetë numër.',
		invalidHeight: 'Lartësia e qelisë duhet të jetë numër.',
		invalidRowSpan: 'Hapësira e rreshtave duhet të jetë numër i plotë.',
		invalidColSpan: 'Hapësira e kolonave duhet të jetë numër i plotë.',
		chooseColor: 'Përzgjidh'
	},
	cellPad: 'Mbushja e qelisë',
	cellSpace: 'Hapësira e qelisë',
	column: {
		menu: 'Kolona',
		insertBefore: 'Vendos Kolonë Para',
		insertAfter: 'Vendos Kolonë Pas',
		deleteColumn: 'Gris Kolonat'
	},
	columns: 'Kolonat',
	deleteTable: 'Gris Tabelën',
	headers: 'Kokat',
	headersBoth: 'Së bashku',
	headersColumn: 'Kolona e parë',
	headersNone: 'Asnjë',
	headersRow: 'Rreshti i Parë',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Madhësia e kufinjve duhet të jetë numër.',
	invalidCellPadding: 'Mbushja e qelisë duhet të jetë numër pozitiv.',
	invalidCellSpacing: 'Hapësira e qelisë duhet të jetë numër pozitiv.',
	invalidCols: 'Numri i kolonave duhet të jetë numër më i madh se 0.',
	invalidHeight: 'Lartësia e tabelës duhet të jetë numër.',
	invalidRows: 'Numri i rreshtave duhet të jetë numër më i madh se 0.',
	invalidWidth: 'Gjerësia e tabelës duhet të jetë numër.',
	menu: 'Karakteristikat e Tabelës',
	row: {
		menu: 'Rreshti',
		insertBefore: 'Shto Rresht Para',
		insertAfter: 'Shto Rresht Prapa',
		deleteRow: 'Gris Rreshtat'
	},
	rows: 'Rreshtat',
	summary: 'Përmbledhje',
	title: 'Karakteristikat e Tabelës',
	toolbar: 'Tabela',
	widthPc: 'përqind',
	widthPx: 'piksell',
	widthUnit: 'njësia e gjerësisë'
} );
